@@ -140,18 +140,19 @@ setMethod("getGaps", "GRanges", function(obj, group.name = NULL, facets = NULL){
         grl <- endoapply(grl, function(dt){
             res <- split(dt, values(dt)[,group.name])
             gps <- gaps(ranges(res))
-            idx <- elementLengths(gps) > 0
+            idx <- elementNROWS(gps) > 0
             res.sub <- res[idx,]
             stds <- unlist(lapply(res.sub, function(x) as.character(strand(x))[1]))
             gps.sub <- gps[idx,]
-            dfs <- values(unlist(res.sub))[cumsum(elementLengths(res.sub)),c(allvars.extra, "stepping"),
+            dfs <- values(unlist(res.sub))[cumsum(elementNROWS(res.sub)),c(allvars.extra, "stepping"),
                                            drop = FALSE]
 
             ir <- unlist(gps.sub)
             if(length(ir)){
                 gr <- GRanges(unique(seqnames(dt)), ir)
-                values(gr) <- dfs[togroup(gps.sub),,drop = FALSE]
-                strand(gr) <- stds[togroup(gps.sub)]
+                values(gr) <- dfs[togroup(PartitioningByWidth(gps.sub)),,
+                                  drop = FALSE]
+                strand(gr) <- stds[togroup(PartitioningByWidth(gps.sub))]
             }else{
                 gr <- GRanges()
             }
@@ -253,7 +254,7 @@ subsetArgsByFormals <- function(args, ..., remove.dots = TRUE){
 }
 
 flatGrl <- function(object, indName = "grl_name"){
-    idx <- togroup(object)
+    idx <- togroup(PartitioningByWidth(object))
     gr <- stack(object, indName)
     values(gr) <-   cbind(values(gr), values(object)[idx,,drop = FALSE])
     gr
@@ -319,7 +320,7 @@ fetch <- function(obj, which, ..., gene.id,
             stop("type for TxDb must be ", .txdb.type)
         if(is.list(which)){
             message("Parsing exons based on which(list) arguments")
-            temp <- exons(obj, vals = which, columns = columns)
+            temp <- exons(obj, columns = columns, filter = which)
             which <- range(temp)
         }
         ## 1st set all the sequences to be inactive:
@@ -458,8 +459,8 @@ fetch <- function(obj, which, ..., gene.id,
         grg <- grglist(obj)
         grg.u <- stack(grg, ".grl.name")
         message("extracting information...")
-        values(grg.u)$junction <- rep(ifelse(elementLengths(grg)>1, TRUE, FALSE),
-                                      times = elementLengths(grg))
+        values(grg.u)$junction <- rep(ifelse(elementNROWS(grg)>1, TRUE, FALSE),
+                                      times = elementNROWS(grg))
         names(grg.u) <- NULL
         res <- grg.u
     }
